*** Macro to label variables
****************************

capture program drop create_labels
	program create_labels 
		syntax [, chances(integer 1) dranking(integer 0)]
	
label variable early_feasible "EarlyOffer: Potential offer from program in Phase 1"
label variable first_early_feasible "FirstEarlyOffer: First offer in Phase 1"
label variable distance "Distance to university (in thousand km)"
label variable distance2 "Distance to university (in thousand km) - squared"
label variable same_land "Program in student's region (Land)"
label variable quota_pctile "Program's ranking of student (between 0 and 1)" 
if "`chances'" == "1" {
label variable chances_phase2 "Chances of not receiving an offer from program in Phase 2" 
}	
if "`dranking'" == "1" {
label variable rk_init2 "Student's initial ranking of program = 2"
label variable rk_init3 "Student's initial ranking of program = 3"
label variable rk_init4 "Student's initial ranking of program = 4"
label variable rk_init5_12 "Student's initial ranking of program = 5 or above"
}	

end;

*** Macro to perform conditional logit estimation
*************************************************

capture program drop clogit_model
	program clogit_model 
	syntax [, y(string) x(string) model(string) niter(integer 16000) showreg(integer 0)]
	
	
if "`showreg'" == "1" {
asclogit `y' `x', case(stu_id) alternatives(pgm_id) iterate(`niter')	
}

if "`showreg'" == "0" {
qui asclogit `y' `x', case(stu_id) alternatives(pgm_id) iterate(`niter')	
}
	
eststo `model'

estadd local fe "Yes"

end

*** Macro to compute marginal effects on acceptance probability
***************************************************************

capture program drop mfx_logit
	program mfx_logit 
	syntax [,  type(string) first_choice_sit(integer 0)]

preserve	

if "`first_choice_sit'" == "1" {
keep if first_choice_sit == 1
}
	
* Create index for choices
sort stu_id pgm_id
by stu_id: generate id_pos = _n
su id_pos 
local max_pos = r(max) 
	
if "`type'"=="early" {
	
gen early_feasible_old = early_feasible
* Baseline predicted probability : no early offer 
replace early_feasible = 0
predict p0
gen p1=.
forval i = 1/`max_pos' {
replace early_feasible = 1 if id_pos==`i'
predict p_temp
replace p1=p_temp if id_pos==`i'
drop p_temp
replace early_feasible = 0 
}
gen baseline = p0
gen diff = (p1- p0)*100
gen marg = (p1-p0)*100 / p0
collapse (mean) mp0=baseline mp1=p1 diff=diff marg=marg, by(stu_id)
collapse (mean) mp0 mp1 diff marg (sd) sd_mp0=mp0 sd_mp1=mp1 sd_diff=diff sd_marg=marg

estadd scalar mp0 = mp0[1]
estadd scalar diff_early = diff[1]
estadd local sd_diff_early = "("+string(sd_diff[1],"%2.1f")+")"
estadd scalar marg_early = marg[1]
estadd local sd_marg_early = "("+string(sd_marg[1],"%2.1f")+")"
estadd local diff_first = ""
estadd local sd_diff_first = ""
estadd local marg_first = ""
estadd local sd_marg_first = ""

}

if "`type'"=="early_first" {

replace early_feasible = 0
replace first_early_feasible = 0
predict p00
gen p10=.
gen p11=.
forval i = 1/`max_pos' {
replace early_feasible = 1 if id_pos==`i'
predict p_temp10
replace first_early_feasible = 1 if id_pos==`i'
predict p_temp11
replace p10=p_temp10 if id_pos==`i'
replace p11=p_temp11 if id_pos==`i'
drop p_temp10 p_temp11
replace early_feasible = 0 
replace first_early_feasible = 0 
}
gen diff_early = (p10- p00)*100
gen marg_early = (p10-p00) *100 / p00
gen diff_first = (p11- p00)*100
gen marg_first = (p11-p00) *100/ p00
gen diff_first_vs_early = (p11- p10)*100
gen marg_first_vs_early = (p11-p10)*100 / p10
collapse (mean) mp00=p00 mp10=p10 mp11=p11 diff_early=diff_early diff_first=diff_first diff_first_vs_early=diff_first_vs_early ///
 marg_early=marg_early marg_first=marg_first marg_first_vs_early=marg_first_vs_early, by(stu_id)
collapse (mean) mp00 mp10 mp11 diff_early diff_first diff_first_vs_early marg_early marg_first marg_first_vs_early ///
(sd) sd_mp00=mp00 sd_mp10=mp10 sd_mp11=mp11 sd_diff_early=diff_early sd_diff_first=diff_first sd_diff_first_vs_early=diff_first_vs_early ///
 sd_marg_early=marg_early sd_marg_first=marg_first sd_marg_first_vs_early=marg_first_vs_early
estadd scalar diff_early = diff_early[1]
estadd local sd_diff_early = "("+string(sd_diff_early[1],"%2.1f")+")"
estadd scalar marg_early = marg_early[1]
estadd local sd_marg_early = "("+string(sd_marg_early[1],"%2.1f")+")"
estadd scalar diff_first = diff_first[1]
estadd local sd_diff_first = "("+string(sd_diff_first[1],"%2.1f")+")"
estadd scalar marg_first = marg_first[1]
estadd local sd_marg_first = "("+string(sd_marg_first[1],"%2.1f")+")"
}

restore

end

*** Macro to compute distance-equivalent utility
************************************************

capture program drop dist_eq_U
	program dist_eq_U 
	syntax

* Distance-equivalent utility of non-first early offer
scalar U_nonfirstearlyoffer =  -1000*(   _b[distance] ///
		  + 2*_b[distance2]*0.126 ///
		  + (4*_b[distance2]*_b[early_feasible] + _b[distance]^2  ///
		  +  4*_b[distance2]^2*(0.126^2) + 4*_b[distance]*_b[distance2]*0.126)^(1/2))/(2*_b[distance2])  
		  
* Distance-equivalent utility of first early offer
scalar U_firstearlyoffer =  -1000*(   _b[distance] ///
		  + 2*_b[distance2]*0.126 ///
		  + (4*_b[distance2]*_b[early_feasible] + 4*_b[distance2]*_b[first_early_feasible] + _b[distance]^2  ///
		  +  4*_b[distance2]^2*(0.126^2) + 4*_b[distance]*_b[distance2]*0.126)^(1/2))/(2*_b[distance2])  
		  
estadd scalar U_nonfirstearlyoffer = U_nonfirstearlyoffer
estadd scalar U_firstearlyoffer = U_firstearlyoffer
	
end

*** Macro for baseline estimation
*********************************

capture program drop baseline_clogit
	program baseline_clogit 
	syntax [, y(string) showreg(integer 0) title(string) table_type(string) table_no(string) print_mfx(integer 0) disteqU(integer 0)]
	
if "`y'" == "" local y "accepted_pgm"

* Create labels 
create_labels

* Column (1): Early offer
clogit_model, y("`y'") x("early_feasible") model("Table_`table_no'_1") showreg(`showreg')
if "`print_mfx'" == "1" {
mfx_logit, type("early")
}

* Column (2): (1) + first early offer
clogit_model, y("`y'") x("early_feasible first_early_feasible") model("Table_`table_no'_2") showreg(`showreg')
if "`print_mfx'" == "1" {
mfx_logit, type("early_first")
}

* Column (3): (2) + distance + same region
clogit_model, y("`y'") x("early_feasible first_early_feasible distance distance2 same_land") model("Table_`table_no'_3")  showreg(`showreg')
if "`print_mfx'" == "1" {
mfx_logit, type("early_first")
}
if "`disteqU'" == "1" {
dist_eq_U
}

* Column (4): (3) + program's ranking of applicant (between 0 and 1)
clogit_model, y("`y'") x("early_feasible first_early_feasible distance distance2 same_land quota_pctile") model("Table_`table_no'_4") showreg(`showreg') 
if "`print_mfx'" == "1" {
mfx_logit, type("early_first")
}
if "`disteqU'" == "1" {
dist_eq_U
}

* Column (5): (4) + chances of not receiving an offer from program in Phase 2
clogit_model, y("`y'") x("early_feasible first_early_feasible distance distance2 same_land quota_pctile chances_phase2") model("Table_`table_no'_5") showreg(`showreg')
if "`print_mfx'" == "1" {
mfx_logit, type("early_first")
}
if "`disteqU'" == "1" {
dist_eq_U
}

local stats 
local lab_stats
local fmts "0 %6.0fc %6.0fc %6.0fc"

if "`print_mfx'" == "1" {
local stats "mp0 diff_early sd_diff_early marg_early sd_marg_early diff_first sd_diff_first marg_first sd_marg_first"
local lab_stats `""Baseline (no early offer) acceptance probability" "Non-first early offer (ppt)" " " "Non-first early offer (%)" " " "First early offer (ppt)" " " "First early offer (%)" " " "'
local fmts `fmts' 3 1 1 1 1 1 1 1
}
if "`disteqU'" == "1" {
local stats `stats' U_nonfirstearlyoffer U_firstearlyoffer
local lab_stats  `"`lab_stats' "Non-first early offer (in km)" "First early offer (in km)" "'
local fmts `fmts' 0
}

esttab Table_`table_no'_1 Table_`table_no'_2 Table_`table_no'_3 Table_`table_no'_4 Table_`table_no'_5 ///
using "${output}/`table_type'table_`table_no'.txt", replace ///
title("`title'") ///
keep(early_feasible first_early_feasible distance distance2 quota_pctile same_land chances_phase2) ///
cells(b(star fmt(3 3 2 2 3 3 3)) se(par fmt(3 3 2 2 3 3 3))) starlevels(* 0.10 ** 0.05 *** 0.01) ///
stats(fe k_alt N_case N ///
`stats', ///
labels("Program fixed effects" "N programs" "N students" "N feasible programs" ///
`lab_stats') fmt(`fmts')) ///
varwidth(60) modelwidth(10 10 10 10 10) ///
label gaps notes nomtitles collabels(none) eqlabels(" ")

end

*** Macro to convert ROL data to exploded form
**********************************************

capture program drop convert_exploded
	program convert_exploded 
	syntax [, pref_rk(string)]

egen nb_ranked_pgm = sum(`pref_rk'>0), by(stu_id)
egen nb_unranked_pgm = sum(`pref_rk'==0), by(stu_id)

gen nb_choice_situations = 0
replace nb_choice_situations = nb_ranked_pgm - 1 if nb_unranked_pgm == 0
replace nb_choice_situations = nb_ranked_pgm if nb_unranked_pgm > 0

tempfile main_data_temp
save `main_data_temp'

forval k=1/12 {
    
use `main_data_temp', clear
	
keep if nb_choice_situations >= `k' & (`pref_rk'==0 | `pref_rk'>=`k')
	
gen choice = (`pref_rk' == `k')

gen double choice_sit_no = stu_id + (`k'/100)
if `k'==1 {
    gen first_choice_sit = 1
}
if `k'>1 {
    gen first_choice_sit = 0
}


tempfile choice_sit_no_`k'
save `choice_sit_no_`k''

}

append using `choice_sit_no_1' `choice_sit_no_2' `choice_sit_no_3' `choice_sit_no_4' `choice_sit_no_5' ///
`choice_sit_no_6'  `choice_sit_no_7'  `choice_sit_no_8'  `choice_sit_no_9'  `choice_sit_no_10' ///
`choice_sit_no_11'  `choice_sit_no_12'
 
preserve

keep choice_sit_no
duplicates drop
sort choice_sit_no

gen choice_sit_id = _n

tempfile choice_sit_id
save `choice_sit_id'

restore

merge m:1 choice_sit_no using `choice_sit_id'
drop choice_sit_no _merge

end

*** Macro to perform rank-order logit estimation (using exploded form)
***********************************************************************

capture program drop rologit_model
	program rologit_model 
	syntax [, y(string) x(string) model(string)]

* Create labels 
create_labels
	
su n_stu 
scalar n_stu = r(max)
su n_pgm
scalar n_pgm = r(max)

qui asclogit `y' `x', case(choice_sit_id) alternatives(pgm_id) 		
	
eststo `model'

estadd scalar n_stu = n_stu
estadd scalar n_pgm = n_pgm
estadd local fe "Yes"

end
