* =============================================================================================
*  Replication program for Figure 2:
*  Julien Grenet, YingHua He, and Dorothea Kübler
*  "Preference Discovery in University Admissions: The Case for Dynamic Multioffer Mechanisms"
*  The Journal of Political Economy
*  28 November 2021
* =============================================================================================

* ------------------------------------------------------------------------ *
* Figure 2 – Activities during the DoSV Procedure (Winter Term of 2015–16) *
* ------------------------------------------------------------------------ *

if "${path}" == "" {
	display "{red: ERROR: Specify path to folder containing replication files in current_directory.do and execute script}"
}
	
global data "${path}\data"
global output "${path}\output"

use "${data}\DoSV_activities.dta", clear

keep if date<=d(2sep2015)

gen up=1
gen low=0

*** FIGURE 2 

* color

twoway (rarea up low date if inrange(date,td(15apr2015),td(16jul2015)),  fc(gs15) lc(bg) lw(none)) ///
(rarea up low date if inrange(date,td(16jul2015),td(19aug2015)),  fc(gs13) lc(bg) lw(none)) ///
(rarea up low date if inrange(date,td(19aug2015),td(25aug2015)),  fc(gs15) lc(bg) lw(none)) ///
(rarea up low date if inrange(date,td(25aug2015),td(2sep2015)),  fc(gs13) lc(bg) lw(none)) ///
(line registrations date, c(stairstep) lp(dash_dot) lcolor(navy) mcolor(navy) msize(small) ylabel(0(0.2)1.1, gmax format(%9.1f))) ///
(line finalized_rol date, c(stairstep)  lp(shortdash)  lcolor(purple) mcolor(navy) msize(small) ylabel(0(0.2)1.1, gmax format(%9.1f))) ///
(line first_offers date, c(stairstep) lp(longdash) lcolor(maroon) mcolor(maroon) msize(small) ylabel(0(0.2)1.1, gmax )) ///
(line exits_all date, c(stairstep) lcolor(forest_green) mcolor(forest_green) msize(small) ylabel(0(0.2)1.1, gmax )) ///
(scatteri 1.02 `=td(27may2015)' 0.95 `=td(27may2015)', recast(line) lw(vthin) color(black) ) ///
(scatteri 1.02 `=td(1aug2015)' 0.95 `=td(1aug2015)', recast(line) lw(vthin) color(black) ) ///
(scatteri 1.02 `=td(22aug2015)' 0.95 `=td(22aug2015)', recast(line) lw(vthin) color(black) ), ///
ylab(0(0.2)1, nogrid) ///
tlabel(15apr2015(7)2sep2015, labsize(tiny)  format(%tdMon_dd)) ///
legend (subtitle("Cumulative fraction of students who", size(medsmall)) symxsize(6)  pos(11) bmargin(3 0 0 20) ring(0) col(1) size(medsmall)  ///
	   order(5 "register with the clearinghouse" 6 "finalize their ROL"  7 "receive an offer"  8 "exit the procedure" ) )	///
xtitle("Date", height(5) axis(1)) ///
ttext(1.06 27may2015 "Application Phase", place(c) size(medsmall)  ) ///
ttext(1.06 1aug2015 "Phase 1", place(c) size(medsmall)  ) ///
ttext(1.06 22aug2015 "Phase 2", place(c) size(medsmall)  ) ///  ) ///
graphregion(margin(t+0) color(white)) bgcolor(white)

graph export "${output}\figure_2_color.pdf", replace

* black & white

twoway (line registrations date, c(stairstep) lp(dash_dot) lcolor(black) mcolor(black) msize(small) ylabel(0(0.2)1.1, gmax format(%9.1f))) ///
(line finalized_rol date, c(stairstep)  lp(shortdash)  lcolor(black) mcolor(black) msize(small) ylabel(0(0.2)1.1, gmax format(%9.1f))) ///
(line first_offers date, c(stairstep) lp(longdash) lcolor(black) mcolor(black) msize(small) ylabel(0(0.2)1.1, gmax )) ///
(line exits_all date, c(stairstep) lcolor(black) mcolor(black) msize(small) ylabel(0(0.2)1.1, gmax )) ///
(scatteri 1.02 `=td(27may2015)' 0.95 `=td(27may2015)', recast(line) lw(vthin) color(black) ) ///
(scatteri 1.02 `=td(1aug2015)' 0.95 `=td(1aug2015)', recast(line) lw(vthin) color(black) ) ///
(scatteri 1.02 `=td(22aug2015)' 0.95 `=td(22aug2015)', recast(line) lw(vthin) color(black) ), ///
ylab(0(0.2)1, glcolor(gs15)) ///
xline(`=d(19aug2015)', lcolor(gs11) lpattern(dash) lw(think)) ///
xline(`=d(16jul2015)', lcolor(gs11) lpattern(dash) lw(think)) ///
xline(`=d(25aug2015)', lcolor(gs11) lpattern(dash) lw(think)) ///
tlabel(15apr2015(7)2sep2015, labsize(tiny)  format(%tdMon_dd)) ///
legend (subtitle("Cumulative fraction of students who", size(medsmall)) symxsize(6)  pos(11) bmargin(3 0 0 20) ring(0) col(1) size(medsmall)  ///
	   order(1 "register with the clearinghouse" 2 "finalize their ROL"  3 "receive an offer"  4 "exit the procedure" ) )	///
xtitle("Date", height(5) axis(1)) ///
ttext(1.06 27may2015 "Application Phase", place(c) size(medsmall)  ) ///
ttext(1.06 1aug2015 "Phase 1", place(c) size(medsmall)  ) ///
ttext(1.06 22aug2015 "Phase 2", place(c) size(medsmall)  ) ///  ) ///
graphregion(margin(t+0) color(white)) bgcolor(white)

graph export "${output}\figure_2.pdf", replace
