* =============================================================================================
*  Replication program for Figure 3:
*  Julien Grenet, YingHua He, and Dorothea Kübler
*  "Preference Discovery in University Admissions: The Case for Dynamic Multioffer Mechanisms"
*  The Journal of Political Economy
*  28 November 2021
* =============================================================================================

* -------------------------------------------------------------------------- *
* Figure 3 – Reasons for exiting the DoSV Procedure (Winter Term of 2015–16) *
* -------------------------------------------------------------------------- *

if "${path}" == "" {
	display "{red: ERROR: Specify path to folder containing replication files in current_directory.do and execute script}"
}

global data "${path}\data"
global output "${path}\output"

use "${data}\DoSV_activities.dta", clear

keep if date>=d(01jul2015) & date<=d(2sep2015)

gen up=1
gen low=0

gen exits_accept_autom_cancel = exits_accept + exits_autom + exits_cancel
gen exits_accept_autom = exits_accept + exits_autom

*** FIGURE 3

* color

twoway (rarea up low date if inrange(date,td(01jul2015),td(16jul2015)),  fc(gs15) lc(bg) lw(none)) ///
(rarea up low date if inrange(date,td(16jul2015),td(19aug2015)),  fc(gs13) lc(bg) lw(none)) ///
(rarea up low date if inrange(date,td(19aug2015),td(25aug2015)),  fc(gs15) lc(bg) lw(none)) ///
(rarea up low date if inrange(date,td(25aug2015),td(2sep2015)),  fc(gs13) lc(bg) lw(none)) ///
(bar exits_all date, bartype(spanning) barwidth(0.5) fc(maroon) lc(maroon) fi(inten100)) ///
(bar exits_accept_autom_cancel date, bartype(spanning) barwidth(0.5) fc(orange) lc(orange) fi(inten100) ) ///
(bar exits_accept_autom date, bartype(spanning) barwidth(0.5) fc(navy) lc(navy) fi(inten100) ) ///
(bar exits_accept date, bartype(spanning) barwidth(0.5) fc(forest_green) lc(forest_green) fi(inten100) ) ///
(line exits_all date, c(stairstep) lcolor(gs5) lw(medthick) mcolor(gs5) msize(small) ylabel(0(0.2)1.1, gmax format(%9.1f))) ///
(line exits_accept_autom_cancel date, c(stairstep) lcolor(gs5) lw(vthin) mcolor(gs5) msize(small) ylabel(0(0.2)1.1, gmax )) ///
(line exits_accept_autom date, c(stairstep) lcolor(gs5) lw(vthin) mcolor(gs5) msize(small) ylabel(0(0.2)1.1, gmax )) ///
(line exits_accept date, c(stairstep) lcolor(gs5) lw(vthin) mcolor(gs5) msize(small) ylabel(0(0.2)1.1, gmax )) ///
(scatteri 1.02 `=td(08jul2015)' 0.95 `=td(08jul2015)', recast(line) lw(vthin) color(black) ) ///
(scatteri 1.02 `=td(1aug2015)' 0.95 `=td(1aug2015)', recast(line) lw(vthin) color(black) ) ///
(scatteri 1.02 `=td(22aug2015)' 0.95 `=td(22aug2015)', recast(line) lw(vthin) color(black) ), ///
ylab(0(0.2)1, nogrid) ///
tlabel(01jul2015(7)2sep2015, labsize(small)  format(%tdMon_dd)) ///
legend (pos(11) bmargin(3 0 0 12) ring(0) col(1) size(medsmall)  ///
	   order(9 "All exits"  ///
			 8 "Actively accept an early offer in Phase 1" ///
			 7 "Automatically assigned to best offer in Phase 2" ///
			 6 "Cancel all applications" ///
			 5 "Participate in Phase 2 but receive no offer" ))	///
xtitle("Date", height(5) axis(1)) ///
ttext(1.06 10jul2015 "Application Phase", place(c) size(medsmall)  ) ///
ttext(1.06 1aug2015 "Phase 1", place(c) size(medsmall)  ) ///
ttext(1.06 22aug2015 "Phase 2", place(c) size(medsmall)  ) ///
graphregion(margin(t+0) color(white)) bgcolor(white) 

graph export "${output}\figure_3_color.pdf", replace

* black & white

twoway (bar exits_all date, bartype(spanning) barwidth(0.5) fc(white) lc(white) fi(inten100)) ///
(bar exits_accept_autom_cancel date, bartype(spanning) barwidth(0.5) fc(white) lc(white) fi(inten100) ) ///
(bar exits_accept_autom date, bartype(spanning) barwidth(0.5) fc(white) lc(white) fi(inten100) ) ///
(bar exits_accept date, bartype(spanning) barwidth(0.5) fc(white) lc(white) fi(inten100) ) ///
(line exits_all date, c(stairstep) lcolor(black) lw(medthick) mcolor(black) msize(small) ylabel(0(0.2)1.1, gmax format(%9.1f))) ///
(line exits_accept_autom_cancel date, c(stairstep) lcolor(black) lw(medium) mcolor(black) msize(small) ylabel(0(0.2)1.1, gmax )) ///
(line exits_accept_autom date, c(stairstep) lcolor(black) lw(medium) mcolor(black) msize(small) ylabel(0(0.2)1.1, gmax )) ///
(line exits_accept date, c(stairstep) lcolor(black) lw(medium) mcolor(black) msize(small) ylabel(0(0.2)1.1, gmax )) ///
(scatteri 1.02 `=td(08jul2015)' 0.95 `=td(08jul2015)', recast(line) lw(vthin) color(black) ) ///
(scatteri 1.02 `=td(1aug2015)' 0.95 `=td(1aug2015)', recast(line) lw(vthin) color(black) ) ///
(scatteri 1.02 `=td(22aug2015)' 0.95 `=td(22aug2015)', recast(line) lw(vthin) color(black) ), ///
ylab(0(0.2)1, glcolor(gs15)) ///
xline(`=d(16jul2015)', lcolor(gs11) lpattern(dash) lw(med)) ///
xline(`=d(19aug2015)', lcolor(gs11) lpattern(dash) lw(med)) ///
xline(`=d(25aug2015)', lcolor(gs11) lpattern(dash) lw(med)) ///
tlabel(01jul2015(7)2sep2015, labsize(small)  format(%tdMon_dd)) ///
legend (pos(11) bmargin(3 0 0 12) ring(0) col(1) size(medsmall)  ///
	   order(5 "All exits"  ///
			 4 "Actively accept an early offer in Phase 1" ///
			 3 "Automatically assigned to best offer in Phase 2" ///
			 2 "Cancel all applications" ///
			 1 "Participate in Phase 2 but receive no offer" ))	///
xtitle("Date", height(5) axis(1)) ///
ttext(1.06 10jul2015 "Application Phase", place(c) size(medsmall)  ) ///
ttext(1.06 1aug2015 "Phase 1", place(c) size(medsmall)  ) ///
ttext(1.06 22aug2015 "Phase 2", place(c) size(medsmall)  ) ///
graphregion(margin(t+0) color(white)) bgcolor(white) 

graph export "${output}\figure_3.pdf", replace
