* =============================================================================================
*  Replication program for Table 5:
*  Julien Grenet, YingHua He, and Dorothea Kübler
*  "Preference Discovery in University Admissions: The Case for Dynamic Multioffer Mechanisms"
*  The Journal of Political Economy
*  28 November 2021
* =============================================================================================

* -------------------------------------------------------------------- *
* Table 5 – Evidence from a Survey on Students in the DoSV for 2015–16 *
* -------------------------------------------------------------------- *

if "${path}" == "" {
	display "{red: ERROR: Specify path to folder containing replication files in current_directory.do and execute script}"
}

global data "${path}\data"
global output "${path}\output"

use "${data}\student_survey.dta", clear

*** PANEL A

* A1
su respondent_id if !missing(n_applications) & n_applications>1
scalar n_A = r(N)
su no_clear_ranking if !missing(n_applications) & n_applications>1
scalar v_A_1 = r(N)
scalar a_A_1 = r(mean)*100

* A2
su wanted_postpone if !missing(n_applications) & n_applications>1
scalar v_A_2 = r(N)
scalar a_A_2 = r(mean)*100

* A3
su received_offer if !missing(n_applications) & n_applications>1
scalar v_A_3 = r(N)
scalar a_A_3 = r(mean)*100

*** PANEL B

gen time_more = (time_spent == 1) if !missing(time_spent)
gen time_same = (time_spent == 0) if !missing(time_spent)
gen time_less = (time_spent == -1) if !missing(time_spent)

* B1a
su respondent_id if !missing(n_applications) & n_applications>1 & received_offer==1
scalar n_B = r(N)
su time_more if !missing(n_applications) & n_applications>1 & received_offer==1
scalar v_B_1a = r(N)
scalar a_B_1a = r(mean)*100

* B1b
su time_same if !missing(n_applications) & n_applications>1 & received_offer==1
scalar v_B_1b = r(N)
scalar a_B_1b = r(mean)*100

* B1c
su time_less if !missing(n_applications) & n_applications>1 & received_offer==1
scalar v_B_1c = r(N)
scalar a_B_1c = r(mean)*100

* B2
su changed_ranking if !missing(n_applications) & n_applications>1 & received_offer==1
scalar v_B2 = r(N)
scalar a_B2 = r(mean)*100

*** PANEL C
su respondent_id if !missing(n_applications) & n_applications>1 & received_offer==1 & changed_ranking==1
scalar n_C = r(N)
su changed_perception if !missing(n_applications) & n_applications>1 & received_offer==1 & changed_ranking==1
scalar v_C_1 = r(N)
scalar a_C_1 = r(mean)*100

foreach men in black {
local col1 90
local col2 105
local width 115

*** TABLE 5

cap log close
set linesize 130
cap log using "${output}/table_5.txt", text replace
	di "Table 5 – Evidence from a Survey on Students in the DoSV for 2015–16"
	di ""
	di _dup(`width') "-"
	di _col(`col1') "Number of" _col(`col2') "Agree/Yes"
	di _col(`col1') "valid answers" _col(`col2') "(%)"
	di _col(`col1') "(1)" _col(`col2') "(2)"
	di _dup(`width') "-"
	di "A. Applied to more than one program (N=" %6.0fc = n_A ")"
	di "" 
	di "At the time of application, I did not have a clear ranking because I still needed to" _col(`col1') %6.0fc = v_A_1 _col(`col2') %3.0f = a_A_1
	di "collect information in order to rank my applications according to my preferences"  
	di ""
	di "Getting to a ranking was very difficult, and I wanted"  							  _col(`col1') %6.0fc = v_A_2 _col(`col2') %3.0f = a_A_2
	di "to postpone this decision for as long as possible"  
	di ""
	di "Received at least one offer"  														  _col(`col1') %6.0fc = v_A_3 _col(`col2') %3.0f = a_A_3
	di ""  
	di "B. Applied to more than one program and received at least one offer (N=" %6.0fc = n_B ")"
	di "" 
	di "When comparing the universities that have made you an offer with"					  
	di "universities that have not, can it then be said that"
	di "" 
	di "   (a) On average, I spend more time collecting information"						  _col(`col1') %6.0fc = v_B_1a _col(`col2') %3.0f = a_B_1a
	di "   on the universities that have made me an offer"
	di "" 
	di "   (b) On average, I spend the same amount of time collecting information"			  _col(`col1') %6.0fc = v_B_1b _col(`col2') %3.0f = a_B_1b
	di "   on the universities that have made me an offer"
	di "" 
	di "   (c) On average, I spend less time collecting information"						  _col(`col1') %6.0fc = v_B_1c _col(`col2') %3.0f = a_B_1c
	di "   on the universities that have made me an offer"
	di "" 
	di "Did your ranking change between the beginning of the procedure"						  _col(`col1') %6.0fc = v_B2 _col(`col2') %3.0f = a_B2
	di "on July 15 and now?"
	di "" 	
	di "C. Applied to more than one program, received at least one offer, and re-ranked programs (N=" %6.0fc = n_C ")"
	di ""
	di "I have received some early offers that have changed my perception"				      _col(`col1') %6.0fc = v_C_1 _col(`col2') %3.0f = a_C_1
	di "of the universities"
	di _dup(`width') "-"
cap log close
}
