* =============================================================================================
*  Replication program for Appendix Figure B1:
*  Julien Grenet, YingHua He, and Dorothea Kübler
*  "Preference Discovery in University Admissions: The Case for Dynamic Multioffer Mechanisms"
*  The Journal of Political Economy
*  28 November 2021
* =============================================================================================

* -------------------------------------------------------------------------------- *
* Appendix Figure B1 – Offer Arrival, Program Selectivity and Program Desirability *
* -------------------------------------------------------------------------------- *

if "${path}" == "" {
	display "{red: ERROR: Specify path to folder containing replication files in current_directory.do and execute script}"
}

global data "${path}\data"
global output "${path}\output"

use "${data}\DoSV_activities.dta", clear

keep date n_pgm_first_offers

keep if date>=d(15jul2015) & date<=d(25aug2015)

gen cum_n_pgm_first_offers = sum(n_pgm_first_offers)

gen up=400
gen low=0

*** APPENDIX FIGURE B1

twoway (rarea up low date if inrange(date,td(17jul2015),td(20jul2015)), fc(gs15) lc(bg) lw(none)) ///
(rarea up low date if inrange(date,td(24jul2015),td(27jul2015)), fc(gs15) lc(bg) lw(none)) ///
(rarea up low date if inrange(date,td(31jul2015),td(03aug2015)), fc(gs15) lc(bg) lw(none)) ///
(rarea up low date if inrange(date,td(07aug2015),td(10aug2015)), fc(gs15) lc(bg) lw(none)) ///
(rarea up low date if inrange(date,td(14aug2015),td(17aug2015)), fc(gs15) lc(bg) lw(none)) ///
(rarea up low date if inrange(date,td(21aug2015),td(24aug2015)), fc(gs15) lc(bg) lw(none)) ///
(scatteri 405 `=td(19aug2015)' 0 `=td(19aug2015)', recast(line) lw(medium) color(red)) ///
(line cum_n_pgm_first_offers date, c(stairstep) lcolor(navy) mcolor(navy) lw(medthick) ylabel(0(50)400, labsize(small) gmax format(%9.0f))), ///
tlabel(16jul2015(5)25aug2015, labsize(small)  format(%tdDD-NN))  ///
graphregion(color(white)) bgcolor(white) ///
xtitle("Date of first batch of offers", height(5) axis(1)) ///
legend(off) ///
ytitle("Cumulative number of programs") ///
ttext(105 1aug2015 "Phase 1", yaxis(1) place(c) size(medsmall) color(black) ) ///
ttext(105 23aug2015 "Phase 2", yaxis(1) place(c) size(medsmall) color(black) )

graph export "${output}\xfigure_B1.pdf", replace
