* =============================================================================================
*  Replication program for Appendix Figure B3:
*  Julien Grenet, YingHua He, and Dorothea Kübler
*  "Preference Discovery in University Admissions: The Case for Dynamic Multioffer Mechanisms"
*  The Journal of Political Economy
*  28 November 2021
* =============================================================================================

* --------------------------------------------------------------------------------------------- *
* Appendix Figure B3 – Distribution of Early Offers and Acceptances across the Days of the Week *
* --------------------------------------------------------------------------------------------- *

if "${path}" == "" {
	display "{red: ERROR: Specify path to folder containing replication files in current_directory.do and execute script}"
}

global data "${path}\data"
global output "${path}\output"

* Macro to add symbol % to stacked bar charts
capture program drop percent
	program  percent
	syntax [, graph(string) ]
local nb=`.`graph'.plotregion1.barlabels.arrnels'
forval i=1/`nb'{
local lab "`.`graph'.plotregion1.barlabels[`i'].text[1]'"
gr_edit .plotregion1.barlabels[`i'].text = {"`lab'%"}
}
end

use "${data}\DoSV_activities.dta", clear

keep date weekday n_offers n_acceptances

keep if date>=d(16jul2015) &  date<=d(18aug2015)

* Because not all weekdays are equally represented, compute weight

egen n_days = sum(!missing(weekday)), by (weekday)
gen weight = 1/n_days

foreach v in offers acceptances {
gen w_n_`v' = n_`v'*weight
egen s_w_n_`v' = sum(w_n_`v'), by(weekday)
egen t_w_n_`v' = sum(w_n_`v')	
gen pct_`v' = 100*s_w_n_`v'/t_w_n_`v'
}

collapse pct_offers pct_acceptances, by(weekday)

label define lab_weekday ///
1 "Monday" 2 "Tuesday" 3 "Wednesday" 4 "Thursday" 5 "Friday" 6 "Saturday" 7 "Sunday"

label values weekday lab_weekday 

*** APPENDIX FIGURE B3

graph bar pct_offers pct_acceptances, over(weekday, label(labsize(small)) ) ///
bar(1, color(maroon) lcolor(gs0)) bar(2, color(navy) lcolor(gs0)) bargap(5)  ///
blabel(total, format(%3.1f) size(small)) name(offers_acceptances, replace) ///
legend (ring(0) pos(1) col(1) order(1 "Early offers" 2 "Acceptances") ) ///
ytitle("Percent", size(medium)) ///
b1title("Day of the week", height(5) size(medium)) ///
graphregion(color(white)) bgcolor(white)

graph export "${output}\xfigure_B3.pdf", replace
