* =============================================================================================
*  Replication program for Appendix Figure C1:
*  Julien Grenet, YingHua He, and Dorothea Kübler
*  "Preference Discovery in University Admissions: The Case for Dynamic Multioffer Mechanisms"
*  The Journal of Political Economy
*  28 November 2021
* =============================================================================================

* ------------------------------------------------- *
* Appendix Figure C1 – Phase 1 Cutoff: Density Test *
* ------------------------------------------------- *

if "${path}" == "" {
	display "{red: ERROR: Specify path to folder containing replication files in current_directory.do and execute script}"
}

global data "${path}\data"
global output "${path}\output"

use "${data}\rd_data.dta", clear

* Drop cutoff student since always receives offer (de Chaisemartin and Behahghel, 2020)
drop if distance_phase1_cutoff == 0

*** Density test

rddensity distance_phase1_cutoff

rddensity distance_phase1_cutoff, plot ///
graph_opt( ///
xline(0, lcolor(black) lwidth(medthin) lpattern(solid)) ///
xtitle("Rank-distance to Phase 1 cutoff of program quota", height(5)) ///
ytitle("Density", height(5)) ///
ylabel(0(0.001)0.004, gmax format(%9.3f)) ///
xlabel(-200(100)200) ///
legend(ring(3) pos(6)) legend(col(2)) ///
legend(label(3 "Density estimate")) ///
legend(label(1 "95% C.I.")) ///
legend(order (3 1)) ///
graphregion(color(white)) bgcolor(white) ///
graphregion(margin(2 2 2 2))  ///
`"text(0.0037 50 "p-value: `: display %4.3f e(pv_q)'", place(c) size(medsmall) justification(left) color(black) )"' ///
) nohistogram ///
esll_opt(lcolor(black))  eslr_opt(lcolor(black))  ///
cirl_opt(color(gs12)) cirr_opt(color(gs12))

*** APPENDIX FIGURE C1

graph export "${output}\xfigure_C1.pdf", replace
