* =============================================================================================
*  Replication program for Appendix Figure C2:
*  Julien Grenet, YingHua He, and Dorothea Kübler
*  "Preference Discovery in University Admissions: The Case for Dynamic Multioffer Mechanisms"
*  The Journal of Political Economy
*  28 November 2021
* =============================================================================================

* -------------------------------------------------------------------------------------------------------- *
* Appendix Figure C2 – Probability of Receiving and Accepting an Early Offer at a Program's Phase 1 Cutoff *
* -------------------------------------------------------------------------------------------------------- *

if "${path}" == "" {
	display "{red: ERROR: Specify path to folder containing replication files in current_directory.do and execute script}"
}

global data "${path}\data"
global output "${path}\output"

use "${data}\rd_data.dta", clear

* Drop cutoff student since always receives offer (de Chaisemartin and Behahghel, 2020)

drop if distance_phase1_cutoff == 0

* Add small noise to feasible so that 
set seed 12345
generate noise = rnormal()
gen feasible_n = feasible
replace feasible_n = feasible + (1/1000)*noise if distance_phase1_cutoff <=0

*** A. Probability of a (potential) early offer form program

rdplot feasible_n distance_phase1_cutoff if distance_phase1_cutoff>=-100 & distance_phase1_cutoff<=100, p(4) ci(95) shade ///
graph_options( ///
xtitle("Rank-distance to Phase 1 cutoff of program quota", height(5)) ///
ytitle("Prob. of receiving early offer from program", height(5)) ///
ylabel(0(0.2)1, gmax format(%9.1f)) ///
xlabel(-100(50)100) ///
legend(ring(3) pos(6)) legend(col(1)) ///
legend(label(1 "95% C.I. for sample mean")) ///
legend(label(4 "Polynomial fit of order 4")) ///
legend(label(3 "Sample average within bin")) ///
legend(order (3 1 4)) ///
graphregion(color(white)) bgcolor(white) ///
graphregion(margin(2 2 2 2))  ///
)

graph export "${output}\xfigure_C2a.pdf", replace

*** B. Probability of accepting an offer from program

rdplot accepted_pgm distance_phase1_cutoff if distance_phase1_cutoff>=-100 & distance_phase1_cutoff<=100, p(4) ci(95) shade ///
graph_options( ///
xtitle("Rank-distance to Phase 1 cutoff of program quota", height(5)) ///
ytitle("Probability of accepting program", height(5)) ///
ylabel(0(0.1)0.6, format(%9.1f)) ///
xlabel(-100(50)100) ///
legend(ring(3) pos(6)) legend(col(1)) ///
legend(label(1 "95% C.I. for sample mean")) ///
legend(label(4 "Polynomial fit of order 4")) ///
legend(label(3 "Sample average within bin")) ///
legend(order (3 1 4)) ///
graphregion(color(white)) bgcolor(white) ///
graphregion(margin(2 2 2 2))  ///
)

*** APPENDIX FIGURE C2

graph export "${output}\xfigure_C2b.pdf", replace
