* =============================================================================================
*  Replication program for Appendix Table B10:
*  Julien Grenet, YingHua He, and Dorothea Kübler
*  "Preference Discovery in University Admissions: The Case for Dynamic Multioffer Mechanisms"
*  The Journal of Political Economy
*  28 November 2021
* =============================================================================================

* ---------------------------------------------------------------------------------------------------------------------------------- *
* Appendix Table B10 – Early Offer and Acceptance among Feasible Programs: Students who Did not Accept an Early Offer until at least *
* Halfway Through Phase 1 																											 *	
* ---------------------------------------------------------------------------------------------------------------------------------- *

if "${path}" == "" {
	display "{red: ERROR: Specify path to folder containing replication files in current_directory.do and execute script}"
}

global data "${path}\data"
global output "${path}\output"

do "${path}\figures_tables\do\macros.do"

use "${data}\main_data.dta", clear
keep if estimation_sample == 1 & feasible == 1

* Restrict to students who did not accept an early offer until at least halfway through Phase 1, i.e., until August 2
keep if stu_date_exit >= mdy(8,2,2015)

* Convert distance to multiple of 1000 km
replace distance = distance / 1000
gen distance2 = distance^2

* Proxy for chances of not receiving an offer in Phase2 
gen chances_phase2 = 0
replace chances_phase2 = ratio_cutoff1 if early_feasible == 0

*** APPENDIX TABLE B10

baseline_clogit, showreg(0) table_type("x") table_no(B10) print_mfx(1) ///
title("Table B10 - Early Offer and Acceptance among Feasible Programs: Students who did not Accept an Early Offer until at least Halfway Through Phase 1")
