* =============================================================================================
*  Replication program for Appendix Table B9:
*  Julien Grenet, YingHua He, and Dorothea Kübler
*  "Preference Discovery in University Admissions: The Case for Dynamic Multioffer Mechanisms"
*  The Journal of Political Economy
*  28 November 2021
* =============================================================================================

* ------------------------------------------------------------------------------------------------------------------------- *
* Appendix Table B9 – Early Offer and Acceptance among Feasible Programs: Students who only Applied to Programs Located in  *
* their Municipality of Residence 																							*
* ------------------------------------------------------------------------------------------------------------------------- *

if "${path}" == "" {
	display "{red: ERROR: Specify path to folder containing replication files in current_directory.do and execute script}"
}

global data "${path}\data"
global output "${path}\output"

do "${path}\figures_tables\do\macros.do"

use "${data}\main_data.dta", clear

* All programs are in the student's city
egen n_same_city = sum(same_city), by(stu_id)
gen all_same_city = (n_same_city == stu_length_init_rol)
keep if all_same_city == 1

keep if estimation_sample == 1 & feasible == 1

* Convert distance to multiple of 1000 km
replace distance = distance / 1000
gen distance2 = distance^2

create_labels, chances(0)

* Col (1) Early offer
clogit_model, y("accepted_pgm") x("early_feasible") niter(100) ///
model("Table_B9_1")
mfx_logit, type("early")

* Col (2) = (1) + first early offer
clogit_model, y("accepted_pgm") x("early_feasible first_early_feasible") niter(100) ///
model("Table_B9_2")
mfx_logit, type("early_first")

* Col (3) = (2) + program's ranking of applicant
clogit_model, y("accepted_pgm") x("early_feasible first_early_feasible quota_pctile") niter(100) ///
model("Table_B9_3")
mfx_logit, type("early_first")

*** APPENDIX TABLE B9

esttab Table_B9_1 Table_B9_2 Table_B9_3 ///
using "${output}\xtable_B9.txt", replace ///
title("Table B9 - Early offer and Acceptance among Feasible Programs: Students who only Applied to Programs Located in their Municipality of Residence") ///
keep(early_feasible first_early_feasible quota_pctile) ///
cells(b(star fmt(3 3 3  3 2)) se(par fmt(3 3 3 3 2))) starlevels(* 0.10 ** 0.05 *** 0.01) ///
stats(fe k_alt N_case N ///
mp0 diff_early sd_diff_early marg_early sd_marg_early diff_first sd_diff_first marg_first sd_marg_first, ///
labels("Program fixed effects" "N programs" "N students" "N feasible programs" ///
"Baseline (no early offer) acceptance probability" "Non-first early offer (ppt)" " " "Non-first early offer (%)" " " "First early offer (ppt)" " " "First early offer (%)" " ") ///
fmt(0 %6.0fc %6.0fc %6.0fc 3 1)) ///
varwidth(60) modelwidth(10 10 10 10 10) ///
label gaps notes nomtitles collabels(none) eqlabels(" ")
