%==========================================================================
%  Replication program for Section IV.D (simulations):
%  Julien Grenet, YingHua He, and Dorothea Kbler
%  "Preference Discovery in University Admissions: The Case for Dynamic Multioffer Mechanisms"
%  The Journal of Political Economy
%  28 November 2021
%==========================================================================

function Feasible = feasible_func(stu_scores_sparse, matched, stu_scores, pgm_id, pgm_capacity)
% feasible_func   Determines each student's set of ex-post feasible programs
%
% Inputs:
% - stu_scores_sparse: (J,I) sparse matrix of student i's score at program j
% - matched: (J,I) matrix indicating whether student i is matched with program k
% - stu_scores: (N,1) vector of student scores
% - pgm_id: (N,1) vector of program identifiers
% - pgm_capacity: (J,1) vector of program capacities
% (I: students / J: programs / N: combinations of students x programs)
%
% Output:
% - Feasible: (N,1) vector indicating whether the program is feasible to the student

[A1, ~, A3] = find(stu_scores_sparse.*matched);
Cutoffs = accumarray(A1, A3, [], @min);   
nb_assigned= sum(matched,2);
Cutoffs(nb_assigned<pgm_capacity) = 0;
Feasible = stu_scores >= Cutoffs(pgm_id);

