%==========================================================================
%  Replication program for Section IV.D (simulations):
%  Julien Grenet, YingHua He, and Dorothea Kbler
%  "Preference Discovery in University Admissions: The Case for Dynamic Multioffer Mechanisms"
%  The Journal of Political Economy
%  28 November 2021
%==========================================================================

function [ranks, invranks] = rank_by_group_func(group_id,y)
% rank_by_group_func   Computes rank order by group
%
% Inputs:
% - group_id: (N,1) vector of group identifier (student or program)
% - y: (N,1) vector of the outcome on which the ranking is base (utility or student score)
% (N: combinations of students x programs)
%
% Output:
% - ranks: (N,1) vector indicating student's ranking of program or program's ranking of student (1: top ranked -> x: bottom ranked / 0: unranked)
% - invranks: (N,1) vector indicating student's inverse ranking of program or program's inverse ranking of student (1: bottom ranked -> x: top ranked / 0: unranked)

% Create ids to sort data back to original sorting
data = [group_id, y, (1:size(group_id,1))'];

% First, sort by group_id, y
data_sorted = sortrows(data,[1 2]);

% Rank of U for each group_id
[~,a] = cellfun(@sort,accumarray(data_sorted(:,1),data_sorted(:,2),[],@(x){x}),'un',0);
invranking = cell2mat(a);

% Sort data back to original form
invranks_data = sortrows([invranking, data_sorted(:,3)],2);
invranks = invranks_data(:,1);

% Then, sort by group_id, -y
data_invsorted = sortrows(data,[1 -2]);

% Inverse rank of U for each group_id
[~,b] = cellfun(@sort,accumarray(data_invsorted(:,1),-data_invsorted(:,2),[],@(x){x}),'un',0);
ranking = cell2mat(b);

% Sort data back to original form
ranks_data = sortrows([ranking, data_invsorted(:,3)],2);
ranks = ranks_data(:,1);
