%==========================================================================
%  Replication program for Section IV.D (simulations):
%  Julien Grenet, YingHua He, and Dorothea Kbler
%  "Preference Discovery in University Admissions: The Case for Dynamic Multioffer Mechanisms"
%  The Journal of Political Economy
%  28 November 2021
%==========================================================================

function relranking = rank_feasible_func(ROLinv,Feasible)
% rank_feasible_func   Computes relative rank order of feasible programs
%
% Inputs:
% - ROLinv: (N_i,M) matrix indicating student i's inverse ranking of program n_i in simulation sample m (1: bottom ranked -> x: top ranked / 0: unranked)
% - Feasible: (N_i,M) vector indicating whether program n_i is feasible to student i in simulation sample m
% (N_i: number of program's ranked by student i)
% 
% Output:
% - relranking: (N,M) vector indicator student i's inverse ranking of program n_i among the ex-post feasible (1: top ranked -> x: bottm ranked / 0: not feasible or unranked)

FeasROLinv = ROLinv.*Feasible;
[~,relranking] = sort(FeasROLinv,1,'descend');
relranking = relranking';
[A1, A2]=ndgrid( 1:size(relranking,1), 1:size(relranking,2) );
relranking(sub2ind(size(relranking), A1, relranking)) = A2; 
relranking = (relranking'.*Feasible);   
    
end
